@@ -22,8 +22,6 @@ CACHE_TIMEOUT = 0  # Not configurable at all
 
 cache = get_cache(CACHE_DATABASE)
 
-local_cache = {}
-
 
 def _get_cache_key(source_currency, target_currency):
     return ':'.join([CACHE_KEY_PREFIX, source_currency, target_currency])
@@ -34,7 +32,6 @@ def update_rates_cached():
     cache_map = {_get_cache_key(rate.source.code, rate.target.code): rate.rate
                  for rate in rates}
     cache.set_many(cache_map, timeout=CACHE_TIMEOUT)
-    local_cache.clear()
     return cache_map
 
 
@@ -45,12 +42,7 @@ def set_cached_rate(source_currency, target_currency, rate):
 
 def get_rate_cached(source_currency, target_currency):
     key = _get_cache_key(source_currency, target_currency)
-    try:
-        rate = local_cache[key]
-    except KeyError:
-        rate = cache.get(key)
-        if rate:
-            local_cache[key] = rate
+    rate = cache.get(key)
     return rate
 
 
